==> pyconfly-0.0.1.tar.gz: pyconfly-0.0.1/README.md <==
# pyconfly

[![License Apache Software License 2.0](https://img.shields.io/pypi/l/pyconfly.svg?color=green)](https://github.com/Karol-G/pyconfly/raw/main/LICENSE)
[![PyPI](https://img.shields.io/pypi/v/pyconfly.svg?color=green)](https://pypi.org/project/pyconfly)
[![Python Version](https://img.shields.io/pypi/pyversions/pyconfly.svg?color=green)](https://python.org)
[![tests](https://github.com/Karol-G/pyconfly/workflows/tests/badge.svg)](https://github.com/Karol-G/pyconfly/actions)
![Unit Tests](https://github.com/Karol-G/pyconfly/actions/workflows/test_and_deploy.yml/badge.svg?branch=main)
[![codecov](https://codecov.io/gh/Karol-G/pyconfly/branch/main/graph/badge.svg)](https://codecov.io/gh/Karol-G/pyconfly)

A simple configuration manager for machine learning projects.

----------------------------------

Project description...

## Installation

You can install `pyconfly` via [pip](https://pypi.org/project/pyconfly/):

    pip install pyconfly




## Contributing

Contributions are very welcome. Tests can be run with [tox], please ensure
the coverage at least stays the same before you submit a pull request.

## License

Distributed under the terms of the [Apache Software License 2.0] license,
"pyconfly" is free and open source software

## Issues

If you encounter any problems, please file an issue along with a detailed description.

[Cookiecutter]: https://github.com/audreyr/cookiecutter
[MIT]: http://opensource.org/licenses/MIT
[BSD-3]: http://opensource.org/licenses/BSD-3-Clause
[GNU GPL v3.0]: http://www.gnu.org/licenses/gpl-3.0.txt
[GNU LGPL v3.0]: http://www.gnu.org/licenses/lgpl-3.0.txt
[Apache Software License 2.0]: http://www.apache.org/licenses/LICENSE-2.0
[Mozilla Public License 2.0]: https://www.mozilla.org/media/MPL/2.0/index.txt

[tox]: https://tox.readthedocs.io/en/latest/
[pip]: https://pypi.org/project/pip/
[PyPI]: https://pypi.org/

==> pyconfly-0.0.6.tar.gz: pyconfly-0.0.6/README.md <==
# Confly

[![License Apache Software License 2.0](https://img.shields.io/pypi/l/pyconfly.svg?color=green)](https://github.com/Karol-G/pyconfly/raw/main/LICENSE)
[![PyPI](https://img.shields.io/pypi/v/pyconfly.svg?color=green)](https://pypi.org/project/pyconfly)
[![Python Version](https://img.shields.io/pypi/pyversions/pyconfly.svg?color=green)](https://python.org)

A simple configuration manager for machine learning projects.

----------------------------------

Project description...

## Installation

You can install `confly` via [pip](https://pypi.org/project/pyconfly/):

    pip install pyconfly




## Contributing

Contributions are very welcome. Tests can be run with [tox], please ensure
the coverage at least stays the same before you submit a pull request.

## License

Distributed under the terms of the [Apache Software License 2.0] license,
"confly" is free and open source software

## Issues

If you encounter any problems, please file an issue along with a detailed description.

[Cookiecutter]: https://github.com/audreyr/cookiecutter
[MIT]: http://opensource.org/licenses/MIT
[BSD-3]: http://opensource.org/licenses/BSD-3-Clause
[GNU GPL v3.0]: http://www.gnu.org/licenses/gpl-3.0.txt
[GNU LGPL v3.0]: http://www.gnu.org/licenses/lgpl-3.0.txt
[Apache Software License 2.0]: http://www.apache.org/licenses/LICENSE-2.0
[Mozilla Public License 2.0]: https://www.mozilla.org/media/MPL/2.0/index.txt

[tox]: https://tox.readthedocs.io/en/latest/
[pip]: https://pypi.org/project/pip/
[PyPI]: https://pypi.org/
